[Zope3-checkins] CVS: Zope3/src/zope/app/publication - zopepublication.py:1.24

Jim Fulton jim@zope.com
Sun, 23 Mar 2003 17:36:11 -0500


Update of /cvs-repository/Zope3/src/zope/app/publication
In directory cvs.zope.org:/tmp/cvs-serv15726/src/zope/app/publication

Modified Files:
	zopepublication.py 
Log Message:
Renamed ++etc++Services to ++etc++site and renamed
++etc++ApplicationController to ++etc++process.


=== Zope3/src/zope/app/publication/zopepublication.py 1.23 => 1.24 ===
--- Zope3/src/zope/app/publication/zopepublication.py:1.23	Thu Mar 20 07:09:01 2003
+++ Zope3/src/zope/app/publication/zopepublication.py	Sun Mar 23 17:35:40 2003
@@ -90,7 +90,7 @@
             # No service manager here, and thus no auth service
             return
 
-        sm = ContextWrapper(sm, ob, name="++etc++Services")
+        sm = ContextWrapper(sm, ob, name="++etc++site")
 
         auth_service = sm.queryService(Authentication)
         if auth_service is None:
@@ -126,11 +126,11 @@
 
     def getApplication(self, request):
 
         # If the first name is '++etc++ApplicationControl', then we should
         # get it rather than look in the database!
         stack = request.getTraversalStack()
 
-        if '++etc++ApplicationController' in stack:
+        if '++etc++process' in stack:
             return applicationControllerRoot
 
         # Open the database.
@@ -126,11 +126,11 @@
     def getApplication(self, request):
 
-        # If the first name is '++etc++ApplicationControl', then we should
+        # If the first name is '++etc++process', then we should
         # get it rather than look in the database!
         stack = request.getTraversalStack()